@@ -35,11 +35,8 @@ class UpdatePayoutAccount:
         try:
             conn.request('POST', (self.route + id), json_data, headers)
             response = conn.getresponse()
-            print("response status >>>" + str(response.status))
-            text = response.read().decode()
-            print("response text >>>" + text)
             if response.status == 200:
-                return json.loads(text)
+                return json.loads(response.read().decode())
             else:
                 return {
                     "code": response.status,
